@@ -1,7 +1,37 @@
+/**
+  Copyright 2021 Univention GmbH
+
+  https://www.univention.de/
+
+  All rights reserved.
+
+  The source code of this program is made available
+  under the terms of the GNU Affero General Public License version 3
+  (GNU AGPL V3) as published by the Free Software Foundation.
+
+  Binary versions of this program provided by Univention to you as
+  well as other copyrighted, protected or trademarked materials like
+  Logos, graphics, fonts, specific documentations and configurations,
+  cryptographic keys etc. are subject to a license agreement between
+  you and Univention and not subject to the GNU AGPL V3.
+
+  In the case you use this program under the terms of the GNU AGPL V3,
+  the program is provided in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+  GNU Affero General Public License for more details.
+
+  You should have received a copy of the GNU Affero General Public
+  License with the Debian GNU/Linux or Univention distribution in file
+  /usr/share/common-licenses/AGPL-3; if not, see
+  <https://www.gnu.org/licenses/>.
+**/
+
+import { mount } from '@vue/test-utils';
+
 import PortalSearch from '@/components/search/PortalSearch';
 import navigation from '@/store/modules/navigation';
 import localize from '@/plugins/localize';
-import { mount } from '@vue/test-utils';
 import Vuex from 'vuex';
 
 
@@ -51,7 +81,7 @@ test('Test Portalsearch', async () => {
 
     // ensure search is triggered by typing
     await input.setValue('univention')
-    expect(store.dispatch).toHaveBeenLastCalledWith('search/setSearchResultsEmpty')
+    expect(store.dispatch).toHaveBeenLastCalledWith("activity/addMessage", {"id": "search", "msg": "0 search results"})
 
     // ensure that after hitting escape the activebutton is set to ''
     await input.trigger('keyup.esc');
